==> lxqt-config_1.2.0.orig.tar.xz: lxqt-config-1.2.0/lxqt-config-appearance/translations/lxqt-config-appearance_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Klik for at skifte farve.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Vælg farve</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK-temaer</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; er blevet overskrevet.&lt;/p&gt;&lt;p&gt;Du kan finde en kopi af dine gamle indstillinger i &apos;%2&apos;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Fejl: gsettings cannot be run</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Standardskrifttype til brugerflade</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Skrifttypenavn:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Punktstørrelse:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Fed kursiv</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Følgende indstillinger påvirker kun nyligt startet programmer</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Brug antialias-skrifttyper</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Skrifttype hintingstil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Let</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Fuld</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Skrifttype hintning</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Opløsning (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Autohint</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Underpixel-antialiasing:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>GTK stil</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Angiv GTK temaer (GTK konfigurationsfiler vil blive overskrevet!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="83"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3-tema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2-tema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="103"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>For at forsøge ensartet tema, vælg enten lignende stil/tema (hvis tilgængelig) på tværs af alle lister, eller vælg &apos;gtk2&apos; Qt-stil (hvis tilgængelig) for at efterligne GTK temaer.

Sørg for at &apos;xsettingsd&apos; er installeret, for at hjælpe GTK programmer med at anvende tema med det samme.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Konfiguration af LXQt udseende</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>KDE-udvidelsen af XDG-ikontemaer -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Farvelæg ikoner baseret på widgetstil (palet)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="94"/>
        <source>(User Theme)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="182"/>
        <source>Open theme folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Paletter</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Flitre...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Konfiguraton af LXQt udseende</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Widget Style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Cursor</source>
        <translation>Markør</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>GTK Style</source>
        <translation type="unfinished">GTK stil</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt-palet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Nogle Qt-stile kan ignorere disse farver.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Vindue:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Visning:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Markering:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>Link:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>Vinduestekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>Vis tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>Markeret tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>Besøgt link:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation>&amp;Gem palette</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation>&amp;indlæs palette</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Standardpalet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="256"/>
        <source>Toolbar button style:</source>
        <translation>Værktøjslinje knapstil:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="264"/>
        <source>Only display the icon</source>
        <translation>Vis kun ikonet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>Only display the text</source>
        <translation>Vis kun teksten</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="274"/>
        <source>The text appears beside the icon</source>
        <translation>Teksten vises ved siden af ikonet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="279"/>
        <source>The text appears under the icon</source>
        <translation>Teksten vises under ikonet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="292"/>
        <source>Activate item on single click</source>
        <translation>Aktivér objekt med ét klik</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt-stil</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <location filename="../styleconfig.cpp" line="255"/>
        <source>Save Palette</source>
        <translation>Gem palette</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <source>Palette name:</source>
        <translation>Palette navn:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="256"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>En palette med samme navn findes allerede.
Ønsker du at erstatte den?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="393"/>
        <source>Remove Palettes</source>
        <translation>Fjern paletter</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="394"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Ønsker du virkelig at fjerne den/de valgte palette(r)
Root paletter vil forblive intakte hvis de findes.</translation>
    </message>
</context>
</TS>

==> lxqt-config_1.3.0.orig.tar.xz: lxqt-config-1.3.0/lxqt-config-appearance/translations/lxqt-config-appearance_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Klik for at skifte farve.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Vælg farve</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK-temaer</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; er blevet overskrevet.&lt;/p&gt;&lt;p&gt;Du kan finde en kopi af dine gamle indstillinger i &apos;%2&apos;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Fejl: gsettings cannot be run</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Standardskrifttype til brugerflade</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Skrifttypenavn:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Punktstørrelse:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Fed kursiv</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Følgende indstillinger påvirker kun nyligt startet programmer</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Brug antialias-skrifttyper</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Skrifttype hintingstil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Let</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Fuld</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Skrifttype hintning</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Opløsning (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Autohint</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Underpixel-antialiasing:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>GTK stil</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Angiv GTK temaer (GTK konfigurationsfiler vil blive overskrevet!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="83"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3-tema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2-tema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="103"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>For at forsøge ensartet tema, vælg enten lignende stil/tema (hvis tilgængelig) på tværs af alle lister, eller vælg &apos;gtk2&apos; Qt-stil (hvis tilgængelig) for at efterligne GTK temaer.

Sørg for at &apos;xsettingsd&apos; er installeret, for at hjælpe GTK programmer med at anvende tema med det samme.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Konfiguration af LXQt udseende</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>KDE-udvidelsen af XDG-ikontemaer -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Farvelæg ikoner baseret på widgetstil (palet)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>Brug baggrundstapet leveret af tema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="94"/>
        <source>(User Theme)</source>
        <translation>(Brugertema)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="182"/>
        <source>Open theme folder</source>
        <translation>Åbn temamappe</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Paletter</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Flitre...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Konfiguraton af LXQt udseende</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Widget Style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Cursor</source>
        <translation>Markør</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>GTK Style</source>
        <translation>GTK stil</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt-palet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Nogle Qt-stile kan ignorere disse farver.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Vindue:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Visning:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Markering:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>Link:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>Vinduestekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>Vis tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>Markeret tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>Besøgt link:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation>&amp;Gem palette</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation>&amp;indlæs palette</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Standardpalet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="256"/>
        <source>Toolbar button style:</source>
        <translation>Værktøjslinje knapstil:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="264"/>
        <source>Only display the icon</source>
        <translation>Vis kun ikonet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>Only display the text</source>
        <translation>Vis kun teksten</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="274"/>
        <source>The text appears beside the icon</source>
        <translation>Teksten vises ved siden af ikonet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="279"/>
        <source>The text appears under the icon</source>
        <translation>Teksten vises under ikonet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="292"/>
        <source>Activate item on single click</source>
        <translation>Aktivér objekt med ét klik</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt-stil</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <location filename="../styleconfig.cpp" line="255"/>
        <source>Save Palette</source>
        <translation>Gem palette</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <source>Palette name:</source>
        <translation>Palette navn:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="256"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>En palette med samme navn findes allerede.
Ønsker du at erstatte den?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="393"/>
        <source>Remove Palettes</source>
        <translation>Fjern paletter</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="394"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Ønsker du virkelig at fjerne den/de valgte palette(r)
Root paletter vil forblive intakte hvis de findes.</translation>
    </message>
</context>
</TS>
